[cig-commits] r14500 - short/3D/PyLith/branches/pylith-swig/playpen/petscapp

brad at geodynamics.org brad at geodynamics.org
Fri Mar 27 15:47:29 PDT 2009


Author: brad
Date: 2009-03-27 15:47:29 -0700 (Fri, 27 Mar 2009)
New Revision: 14500

Modified:
   short/3D/PyLith/branches/pylith-swig/playpen/petscapp/fooapp.py
Log:
Updated.

Modified: short/3D/PyLith/branches/pylith-swig/playpen/petscapp/fooapp.py
===================================================================
--- short/3D/PyLith/branches/pylith-swig/playpen/petscapp/fooapp.py	2009-03-27 22:45:24 UTC (rev 14499)
+++ short/3D/PyLith/branches/pylith-swig/playpen/petscapp/fooapp.py	2009-03-27 22:47:29 UTC (rev 14500)
@@ -20,7 +20,8 @@
 
   def main(self, *args, **kwds):
     """
-    Run simulation in parallel on compute nodes.
+    Run simulation in parallel on compute nodes. Would be
+    onComputeNodes() in a real Pyre mpi application.
     """
     print "Call PetscInitialize()."
     self.fake_main(*args, **kwds)
@@ -142,7 +143,8 @@
 
   def fake_main(self, *args, **kwds):
     """
-    Run the application.
+    Run the application. Would be called the usual main() in a real
+    application.
     """
     print "Doing some stuff in main."
     print "Foo:"



More information about the CIG-COMMITS mailing list